@@ -236,12 +236,12 @@ class TestGraphSet(unittest.TestCase):
 
         # called as instance methods
         gs = GraphSet.graphs(no_loop=True)
-        gs.connected_components([1, 3, 5])
-        gs.cliques(4)
-        gs.trees(1)
-        gs.forests([1, 3])
-        gs.cycles()
-        gs.paths(1, 6)
+        _ = gs.connected_components([1, 3, 5])
+        _ = gs.cliques(4)
+        _ = gs.trees(1)
+        _ = gs.forests([1, 3])
+        _ = gs.cycles()
+        _ = gs.paths(1, 6)
 
         # exceptions
         self.assertRaises(KeyError, GraphSet.graphs, vertex_groups=[[7]])
@@ -624,20 +624,19 @@ class TestGraphSet(unittest.TestCase):
         gs = GraphSet()
         st = gs.dumps()
         self.assertEqual(st, "B\n.\n")
-        gs.loads(st)
+        gs = GraphSet.loads(st)
         self.assertEqual(gs, GraphSet())
 
         gs = GraphSet([g0])
         st = gs.dumps()
         self.assertEqual(st, "T\n.\n")
-        gs.loads(st)
+        gs = GraphSet.loads(st)
         self.assertEqual(gs, GraphSet([g0]))
 
         v = [g0, g1, g12, g123, g1234, g134, g14, g4]
         gs = GraphSet(v)
         st = gs.dumps()
-        gs = GraphSet()
-        gs.loads(st)
+        gs = GraphSet.loads(st)
         self.assertEqual(gs, GraphSet(v))
 
         # skip this test, becasue string is treated as an element
@@ -646,9 +645,8 @@ class TestGraphSet(unittest.TestCase):
 
         f = tempfile.TemporaryFile()
         gs.dump(f)
-        gs = GraphSet()
         f.seek(0)
-        gs.load(f)
+        gs = GraphSet.load(f)
         self.assertEqual(gs, GraphSet(v))
 
     def test_networkx(self):
@@ -658,8 +656,8 @@ class TestGraphSet(unittest.TestCase):
             return
 
         try:
-            GraphSet.converters = { 'to_graph': nx.Graph,
-                                    'to_edges': nx.Graph.edges }
+            GraphSet.converters['to_graph'] = nx.Graph
+            GraphSet.converters['to_edges'] = nx.Graph.edges
 
             g = nx.grid_2d_graph(3, 3)
             GraphSet.set_universe(g)
@@ -680,8 +678,8 @@ class TestGraphSet(unittest.TestCase):
         except:
             raise
         finally:
-            GraphSet.converters = { 'to_graph': lambda edges: edges,
-                                    'to_edges': lambda graph: graph }
+            GraphSet.converters['to_graph'] = lambda edges: edges
+            GraphSet.converters['to_edges'] = lambda graph: graph
 
     def test_large(self):
         try:
@@ -690,14 +688,15 @@ class TestGraphSet(unittest.TestCase):
             return
 
         try:
+            GraphSet.converters['to_graph'] = nx.Graph
             GraphSet.converters['to_edges'] = nx.Graph.edges
 
             g = nx.grid_2d_graph(8, 8)
             v00, v01, v10 = (0,0), (0,1), (1,0)
 
             GraphSet.set_universe(g)
-            self.assertEqual(len(GraphSet.universe()), 112)
-#            self.assertEqual(GraphSet.universe()[:2], [(v00, v01), (v00, v10)])
+            self.assertEqual(len(GraphSet.universe().edges()), 112)
+#            self.assertEqual(GraphSet.universe().edges()[:2], [(v00, v01), (v00, v10)])
 
             gs = GraphSet({});
             gs -= GraphSet([nx.Graph([(v00, v01)]),
@@ -714,6 +713,7 @@ class TestGraphSet(unittest.TestCase):
         except:
             raise
         finally:
+            GraphSet.converters['to_graph'] = lambda edges: edges
             GraphSet.converters['to_edges'] = lambda graph: graph
 
 
